/* Borodulin Fedor 10-1 PML 30 */

#define _CRT_SECURE_NO_WARNINGS

/* Math includes */
#include <cmath>
#include <xmmintrin.h>
#include <immintrin.h>

/* I/O includes */
#include <cstdio>

/* Built-in data structures includes */
#include <vector>
#include <map>
#include <deque>
#include <string>
#include <set>

/* Other includes */
#include <algorithm>
#include <functional>
#include <thread>

/* Basic data types definitions */
using int64 = long long;
using uint64 = unsigned long long;
using flt = float;
using dbl = double;
using int_set = std::set<int64>;

/* Task C entry point */
void TaskC( void )
{
  const auto GetDivisors {[]( int64 Val ) -> int_set
  {
    int_set Set {};
    int64 i;

    for (i = 2; i * i < Val; i++)
      if (Val % i == 0)
        Set.emplace(i), Set.emplace(Val / i);

    if (i * i == Val)
      Set.emplace(i);

    Set.emplace(Val);

    return Set;
  }};

  /* true if <= 1, otherwise - false */
  const auto CheckSameCnt {[]( const int_set &Set1, const int_set &Set2 ) -> bool
  {
    int64 Cnt {};
    auto
      Iter1 {Set1.begin()},
      Iter2 {Set2.begin()};

    while (true)
    {
      while (Iter1 != Set1.end() &&
             *Iter1 < *Iter2)
        Iter1++;

      while (Iter2 != Set2.end() &&
             *Iter2 < *Iter1)
        Iter2++;

      if (Iter1 == Set1.end() ||
          Iter2 == Set2.end())
        break;

      if (*Iter1 == *Iter2)
        Cnt++, Iter1++;
    }

    return Cnt <= 1;
  }};

  int64 X, L, R;

  scanf("%lli %lli %lli", &X, &L, &R);

  int_set XDivisors {std::move(GetDivisors(X))};

  std::vector<int64> Res {};

  for (int64 i {L}; i <= R; i++)
    if (i != X && CheckSameCnt(XDivisors, GetDivisors(i)))
      Res.emplace_back(i);

  printf("%llu\n", Res.size());

  for (int64 i {0}; (i + 1) < Res.size(); i++)
    printf("%lli ", Res[i]);

  if (!Res.empty())
    printf("%lli\n", Res.back());
} /* End of 'TaskC' function */

/* Task D entry point */
void TaskD( void )
{
  struct elm
  {
  public:
    int64 Val;
    std::deque<std::vector<int64>> AllSums;
  };

  const auto CheckSeq {[]( const std::vector<int64> &Seq ) -> bool
  {
    for (int64 i {2}; i < Seq.size(); i++)
      if ((Seq[i - 2] + Seq[i]) == (Seq[i - 1] << 1))
        return false;

    return true;
  }};

  int64 Val;

  scanf("%lli", &Val);

  std::deque<elm> Dp {};
  Dp.emplace_back(std::move(elm {1, {{1}}}));

  for (int64 i {2}; i <= Val; i++)
  {
    elm tmp {i, {{i}}};

    for (auto &Prev : Dp)
    {
      const int64 Diff {i - Prev.Val};
      for (auto &Seq : Prev.AllSums)
      {
        if (Diff > Seq.back())
          tmp.AllSums.emplace_back(Seq),
          tmp.AllSums.back().emplace_back(Diff);

        if (!CheckSeq(tmp.AllSums.back()))
          tmp.AllSums.pop_back();
      }
    }

    Dp.emplace_back(std::move(tmp));
  }

  for (auto &Sum : Dp.back().AllSums)
  {
    for (int64 i {0}; (i + 1) < Sum.size(); i++)
      printf("%lli+", Sum[i]);

    printf("%lli\n", Sum.back());
  }
} /* End of 'TaskD' function */

/* Task E entry point */
void TaskE( void )
{
  const int64 ThreadsCnt {std::thread::hardware_concurrency()};

  std::vector<std::thread> ThreadsPool {};
  std::vector<int64> ValuesPool {};
  ValuesPool.resize(ThreadsCnt);

  int64 Val, Divisior;

  scanf("%lli %lli", &Val, &Divisior);

  std::vector<int64> Arr {};
  Arr.resize(Val);

  for (int64 i {0}; i < Val; i++)
    scanf("%lli", Arr.data() + i);

  dbl ThreadSize {(dbl)Val / ThreadsCnt};

  const std::function<int( int64, int64 * )> ThreadFunc
  {[&Val, &Divisior, &ThreadsCnt, &Arr]( int64 Segment, int64 *Res ) -> int
  {
    const int64
      Num {Segment & 0xffffffff},
      GlbCnt {(Segment >> 0x20) & 0xffffffff},
      Len {Val}, Div {Divisior};

    for (int64 i {Num}; i < Len; i += GlbCnt)
    {
      int64 Mod {};

      for (int64 j {i}; j < Len; j++)
      {
        Mod = (Mod + Arr[j]) % Div;

        *Res += Mod == 0;
      }
    }

    return 0;
  }};

  for (int64 i {0}, Offset {0}; i < ThreadsCnt; i++)
  {
    int64 NewOffset {(int64)((i + 1) * ThreadSize)};

    ThreadsPool.emplace_back(ThreadFunc, (i | (ThreadsCnt << 0x20)),
                             ValuesPool.data() + 1);
  }

  int64 Res {0};

  for (auto &Elm : ThreadsPool)
    Elm.join();

  for (auto &Elm : ValuesPool)
    Res += Elm;

  printf("%lli\n", Res);
} /* End of 'TaskE' function */

/* Programm entry point */
int main( void )
{
  TaskE();

  return 0;
} /* End of 'main' function */

/* END OF 'main.cpp' FILE */
